# Experiment 1A
# 0 Preliminaries
library(nlme)
library(lattice)
set.seed(1234321)
old.settings <- trellis.par.get()        
library(gdata)
library(gtools)
library(gplots)

# 1 Input
data=read.table("pi1.dat", header=TRUE, dec=".")
gdata <- groupedData(logrt ~ 1 | vp, data=data, order.groups = F)

model1 <- lme(logrt ~ oswitch+repet+repside+lag, random = pdDiag(~ oswitch+repet+repside+lag), 
          data = gdata, method="ML")

# add the 4 meaningful 2-way interactions as fixed effects
model2a <- update(model1, logrt ~ oswitch+repet+repside+lag+oswitch*repet)
model2b <- update(model1, logrt ~ oswitch+repet+repside+lag+oswitch*repside)
model2c <- update(model1, logrt ~ oswitch+repet+repside+lag+oswitch*lag)
model2d <- update(model1, logrt ~ oswitch+repet+repside+lag+repside*lag)

anova(model1, model2a)
anova(model1, model2b)
anova(model1, model2c)
anova(model1, model2d)
#only 2a is better on all 3 fit indices than 1 --> retain 2a

# add random effect of interaction (those of main effects are already in 2a by default!)
model3a <- update(model2a, random = pdDiag(~ oswitch+repet+repside+lag+oswitch*repet))
anova(model2a, model3a)
# no improvement (p = .99)

## now follow through the most successful model, including higher-order interactions
model4 <- update(model2a, logrt ~ oswitch+repet+repside+lag+
                                  oswitch*repside + oswitch*lag + repside*lag + oswitch*repside*lag)
model4a <- update(model4, random = pdDiag(~ oswitch+repet+repside+lag+oswitch*repside+oswitch*repside*lag))
anova(model2a, model4, model4a)
# model2a wins (no sign of improvement by the other models)

## now take best model so far and drop random effects 
model5a <- update(model2a, random = pdDiag(~ oswitch+repet+repside))
model5b <- update(model2a, random = pdDiag(~ oswitch+repet+lag))
model5c <- update(model2a, random = pdDiag(~ oswitch+repside+lag))
model5d <- update(model2a, random = pdDiag(~ repet+repside+lag))
anova(model2a, model5a)
anova(model2a, model5b)
anova(model2a, model5c)
anova(model2a, model5d)
# the first three simplifications incur no sign loss of fit --> 
model5e <- update(model2a, random = ~oswitch)
anova(model2a, model5e)
# no loss of fit --> keep 5e

# removing repet and oswitch*repet improves fit (just so on BIC)
model5f <- update(model5e, fixed = ~ oswitch+repside+lag)

# test whether adding upstep improves fit
model6 <- update(model5f, fixed = ~oswitch+repside+lag+upstep)
anova(model5f, model6)
# no improvement of fit --> keep 5f

## finally, try to remove fixed effects to test their significance 

model6a <- update(model5f, fixed = ~ oswitch+repside)
model6b <- update(model5f, fixed = ~ oswitch+lag)
model6c <- update(model5f, fixed = ~ repside+lag, random=~1)
#lme does not allow to remove main effects while including the interaction!
anova(model5f,model6a)
anova(model5f,model6b)
anova(model5f,model6c)

source("Rsquared.R")
R <- Rsquared(model5f, gdata$logrt)
R

intervals(model5f)

save(model5f, file = "pi1model5f.rda")




################ Visualization ##################################

load("pi1model5f.rda")
gdata$logpred <- predict(model5f,level=1)
gdata$rt <- exp(gdata$logrt)
gdata$pred <- exp(gdata$logpred)
write.table(gdata, file = "pi1.predobs.dat", append = FALSE, quote = FALSE, sep = " ")
### writes out for SPSS --> aggregate by conditions and read again!

aggrdata=read.table("pi1.aggr.dat", header=TRUE, dec=".")
aggrdata$condition <- 1000*(aggrdata$oswitch+1) + 100*(aggrdata$repet+1) + 10*(aggrdata$repside+2) + (aggrdata$lag+1)
#oswitch 1 = no, 2 = yes / repet: 1 = new, 2 = repeated / repside: 1 = same side, 2 = new, 3 = other side 
rdata <- reshape(aggrdata, idvar="vp", timevar="condition", drop=c("oswitch","repet","repside","lag","logrt","logpred"), direction="wide")
noswi.new <- rdata$rt.1121   #non-repeated items
noswi.ss.obs <- rdata[,c(4,6,8,10)]
noswi.ss.pred <- rdata[,c(5,7,9,11)]
noswi.os.obs <- rdata[,c(14,16,18)]
noswi.os.pred <- rdata[,c(15,17,19)]
swi.new <- rdata$rt.2121 
swi.ss.obs <- rdata[,c(22,24,26)]
swi.ss.pred <- rdata[,c(23,25,27)]
swi.os.obs <- rdata[,c(30,32,34,36)]
swi.os.pred <- rdata[,c(31,33,35,37)]

#Bakeman-McArthur correction
noswi.mean <- rowMeans(cbind(noswi.ss.obs, noswi.os.obs), na.rm=T)
noswi.ss.obs <- noswi.ss.obs - noswi.mean + mean(noswi.mean, na.rm=T)
noswi.os.obs <- noswi.os.obs - noswi.mean + mean(noswi.mean, na.rm=T)
swi.mean <- rowMeans(cbind(swi.ss.obs, swi.os.obs),na.rm=T)
swi.ss.obs <- swi.ss.obs - swi.mean + mean(swi.mean, na.rm=T)
swi.os.obs <- swi.os.obs - swi.mean + mean(swi.mean, na.rm=T)


source("plot.confint.R")
pt = c(1,0,17,0)
# point styles
par(font.main=1)
par(cex = 1.2)
#increases all text --> good for PowerPoint
cl <- c("black", "black", "black", "black")
#for print
#cl <- c("black", "red", "black", "blue")
#for PowerPoint
ltype <- c(1,1,2,2)
names <- c("1", "2", "3", "4+")

par(mfrow=c(2,1))
par(cex=0.7)
par(mar=c(4.5,4,3,3))
# bottom, left, top, right margins (in lines)

### no switch

x11()
plot.confint(noswi.ss.obs, c(1:4), c(1:4), 0.05, xlim = c(0.5,4.5), ylim=c(0.5,1.3), cex=1.5,
             pch=pt[1], lty=ltype[1], xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot(c(1:4), colMeans(noswi.ss.pred), xlim=c(0.5,4.5), ylim=c(0.5,1.3), type = "l", 
             pch=pt[2], lty=ltype[2], cex=2, lwd=3, xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot.confint(noswi.os.obs, c(1:3), c(1,3,4), -0.05, xlim = c(0.5,4.5), ylim=c(0.5,1.3), cex=1.5,
             pch=pt[3], lty=ltype[3], xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot(c(1,3,4), colMeans(noswi.os.pred), xlim=c(0.5,4.5), ylim=c(0.5,1.3), type = "l", 
             pch=pt[4], lty=ltype[4], cex=2, lwd=3, xlab="Lag", ylab="RT (s)", axes=F)

axis(side=1, at=c(1:4), labels=names)
axis(2) #brings back y-axis
box()   #brings back the frame
legend(0.5, 1.1, legend=c("same side", "other side"), 
        col=cl[c(1,3)], lty=ltype[c(1,3)], pch=pt[c(1,3)], xjust=0, yjust=0)
polygon(x=c(0,5), y=c(mean(noswi.new),mean(noswi.new)))
title(main="No location switch")

### location switch

x11()
plot.confint(na.omit(swi.ss.obs), c(1:3), c(1,3,4), 0.05, xlim = c(0.5,4.5), ylim=c(0.5,1.3), cex=1.5,
             pch=pt[1], lty=ltype[1], xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot(c(1,3,4), colMeans(na.omit(swi.ss.pred)), xlim=c(0.5,4.5), ylim=c(0.5,1.3), type = "l", 
             pch=pt[2], lty=ltype[2], cex=2, lwd=3, xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot.confint(swi.os.obs, c(1:4), c(1:4), -0.05, xlim = c(0.5,4.5), ylim=c(0.5,1.3), cex=1.5,
             pch=pt[3], lty=ltype[3], xlab="Lag", ylab="RT (s)", axes=F)
par(new=T)
plot(c(1:4), colMeans(swi.os.pred), xlim=c(0.5,4.5), ylim=c(0.5,1.3), type = "l", 
             pch=pt[4], lty=ltype[4], cex=2, lwd=3, xlab="Lag", ylab="RT (s)", axes=F)

axis(side=1, at=c(1:4), labels=names)
axis(2) #brings back y-axis
box()   #brings back the frame
legend(0.5, 0.6, legend=c("same side", "other side"), 
        col=cl[c(1,3)], lty=ltype[c(1,3)], pch=pt[c(1,3)], xjust=0, yjust=0)
polygon(x=c(0,5), y=c(mean(swi.new),mean(swi.new)))
title(main="Location switch")
